@@ -1,32 +1,40 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2016-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef NOTE_H
 #define NOTE_H
 
 #include "kcontacts_export.h"
-
-#include <QMap>
 #include <QSharedDataPointer>
 #include <QString>
-
-namespace KContacts
-{
-class ParameterMap;
+#include <QMap>
 
 /** @short Class that holds a Note for a contact.
  *  @since 5.3
  */
+namespace KContacts
+{
 class KCONTACTS_EXPORT Note
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Note &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, Note &);
-    friend class VCardTool;
-
 public:
     Note();
     Note(const Note &other);
@@ -37,44 +45,27 @@ public:
     typedef QVector<Note> List;
 
     void setNote(const QString &note);
-    Q_REQUIRED_RESULT QString note() const;
+    QString note() const;
 
-    Q_REQUIRED_RESULT bool isValid() const;
+    bool isValid() const;
 
-#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
-    /**
-     * @deprecated Since 5.88 for lack of usage
-     */
-    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     void setParameters(const QMap<QString, QStringList> &params);
-#endif
-
-#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
-    /**
-     * @deprecated Since 5.88 for lack of usage
-     */
-    Q_REQUIRED_RESULT
-    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     QMap<QString, QStringList> parameters() const;
-#endif
 
-    Q_REQUIRED_RESULT bool operator==(const Note &other) const;
-    Q_REQUIRED_RESULT bool operator!=(const Note &other) const;
+    bool operator==(const Note &other) const;
+    bool operator!=(const Note &other) const;
 
     Note &operator=(const Note &other);
 
-    Q_REQUIRED_RESULT QString toString() const;
-
+    QString toString() const;
 private:
-    void setParams(const ParameterMap &params);
-    Q_REQUIRED_RESULT ParameterMap params() const;
-
     class Private;
     QSharedDataPointer<Private> d;
 };
 KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Note &object);
 
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Note &object);
+
 }
 Q_DECLARE_TYPEINFO(KContacts::Note, Q_MOVABLE_TYPE);
 #endif // NOTE_H
